Module logutil

Module logutil 

Structs

CPMsgRecord
CPMsgRecord stands for command palette record which used to pass the logging message from slog object to view objet by LAST_LOG_TO_DISPLAY
CommandPaletteDrain
CompoundDecorator
CompoundRecordDecorator

Enums

TargetLog

Statics

LAST_LOG_TO_DISPLAY
LAST_LOG_TO_DISPLAY here is used to pass msg to CommandPalette.
LOG_TARGET

Functions

get_current_log_target
get_last_log_to_display
get_logger
set_current_log_target