Struct below_common::logutil::CPMsgRecord
source · [−]pub struct CPMsgRecord { /* private fields */ }Expand description
CPMsgRecord stands for command palette record which used to pass the logging message from slog object to view objet by LAST_LOG_TO_DISPLAY
Implementations