Struct below_common::logutil::CompoundRecordDecorator
source · [−]Trait Implementations
sourceimpl<'a, W, T> Drop for CompoundRecordDecorator<'a, W, T>where
W: Write,
T: Write,
impl<'a, W, T> Drop for CompoundRecordDecorator<'a, W, T>where
W: Write,
T: Write,
sourceimpl<'a, W, T> RecordDecorator for CompoundRecordDecorator<'a, W, T>where
W: Write,
T: Write,
impl<'a, W, T> RecordDecorator for CompoundRecordDecorator<'a, W, T>where
W: Write,
T: Write,
sourcefn start_whitespace(&mut self) -> Result<(), Error>
fn start_whitespace(&mut self) -> Result<(), Error>
Format normal text
sourcefn start_timestamp(&mut self) -> Result<(), Error>
fn start_timestamp(&mut self) -> Result<(), Error>
Format timestamp
sourcefn start_level(&mut self) -> Result<(), Error>
fn start_level(&mut self) -> Result<(), Error>
Format Record level
sourcefn start_comma(&mut self) -> Result<(), Error>
fn start_comma(&mut self) -> Result<(), Error>
Format a comma between key-value pairs
sourcefn start_value(&mut self) -> Result<(), Error>
fn start_value(&mut self) -> Result<(), Error>
Format a value
sourcefn start_location(&mut self) -> Result<(), Error>
fn start_location(&mut self) -> Result<(), Error>
Format a file location
sourcefn start_separator(&mut self) -> Result<(), Error>
fn start_separator(&mut self) -> Result<(), Error>
Format value
sourceimpl<'a, W, T> Write for CompoundRecordDecorator<'a, W, T>where
W: Write,
T: Write,
impl<'a, W, T> Write for CompoundRecordDecorator<'a, W, T>where
W: Write,
T: Write,
sourcefn write(&mut self, buf: &[u8]) -> Result<usize>
fn write(&mut self, buf: &[u8]) -> Result<usize>
Write a buffer into this writer, returning how many bytes were written. Read more
sourcefn flush(&mut self) -> Result<()>
fn flush(&mut self) -> Result<()>
Flush this output stream, ensuring that all intermediately buffered contents reach their destination. Read more
sourcefn is_write_vectored(&self) -> bool
fn is_write_vectored(&self) -> bool
can_vector)Determines if this Writer has an efficient write_vectored
implementation. Read more
1.0.0 · sourcefn write_all(&mut self, buf: &[u8]) -> Result<(), Error>
fn write_all(&mut self, buf: &[u8]) -> Result<(), Error>
Attempts to write an entire buffer into this writer. Read more
sourcefn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<(), Error>
fn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<(), Error>
write_all_vectored)Attempts to write multiple buffers into this writer. Read more